-- cache getspellinfo for performance
local spellcache = setmetatable({}, {__index=function(t,v) local a = {GetSpellInfo(v)} if GetSpellInfo(v) then t[v] = a end return a end})
local function GetSpellInfo(a)
	return unpack(spellcache[a])
end
-- load lbb
local bosstable = LibStub("LibBabble-Boss-3.0"):GetLookupTable()
-- Marrowgar
local loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("marrowgar",
	bosstable["Lord Marrowgar"],
	{
		healthtrack={[36612]=true,[38711]=false},
		manatrack={},
		phases={["1"]="Combat", ["2"]="Bone storm"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 36612 or did == 36612 then
				return true
			end
		end,
	},
	{
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...)
			if (select(10,...))==(GetSpellInfo(70814)) then
				EnterPhase("1")
			elseif (select(10,...))==(GetSpellInfo(70835)) then
				EnterPhase("2")
			end
		end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 600) end,
		["ALL_OUT_OF_COMBAT"] = function() DisengageEncounter() end,
	}
)
if not loadSuccess then
	print("Load of "..bosstable["Lord Marrowgar"].." failed: "..StatusSubscribe.locale[errorMsg])
end

--lady deathwhisper
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("deathwhisper",
	bosstable["Lady Deathwhisper"],
	{
		healthtrack={[36855]=true,[38010]=false,[37949]=false,[37890]=false,[38009]=false},
		manatrack={[36855]=true},
		phases={["1"]="Mana Shield", ["2"]="Engage"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = (tonumber((select(3,...)):sub(9,12),16) == 36855)
			local did = (tonumber((select(6,...)):sub(9,12),16) == 36855)
			if (sid and (not did)) or (did and (not sid)) then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 600) TimerCreate("Mana shield", "dcount", 100) end,
		["UNIT_MANA"] = function(unit) if (tonumber(UnitGUID(unit):sub(9,12),16)) == 36855 then TimerSet("Mana shield", math.floor((UnitPower(unit)/UnitPowerMax(unit))*100)) end end,
		["COMBAT_LOG_EVENT_UNFILTERED"]=function(...) if (select(9,...))==70842 and (select(2,...)) == "SPELL_AURA_REMOVED" then TimerKill("Mana shield") EnterPhase("2") end end,
	}
)
if not loadSuccess then
	print("Load of "..bosstable["Lady Deathwhisper"].." failed: "..StatusSubscribe.locale[errorMsg])
end

--gunship battle
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("gunship",
	bosstable["Icecrown Gunship Battle"],
	{
		healthtrack={[37540]=true,[34215]=true,[37117]=false,[37116]=false},
		manatrack={},
		phases={[""]="Engaged"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 37540 or did == 37540 or sid == 34215 or did == 34215 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("") end,
	}
)
if not loadSuccess then
	print("Load of "..bosstable["Icecrown Gunship Battle"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- deathbringer saurfang
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("deathbringer",
	bosstable["Deathbringer Saurfang"],
	{
		healthtrack={[37813]=true,[38508]=false},
		manatrack={},
		phases={["1"]="Engaged", ["2"]="Frenzy"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 37813 or did == 37813 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 480) TimerCreate("Blood power", "ucount", 100) end,
		["UNIT_ENERGY"] = function(unit) if tonumber(UnitGUID(unit):sub(9,12),16) == 37813 then TimerSet("Blood power", UnitPower(unit)) end end,
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...) if (select(9,...)) == 72737 then EnterPhase("2") end end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Deathbringer Saurfang"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- rotface
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("rotface",
	bosstable["Rotface"],
	{
		healthtrack={[36627]=true},
		manatrack={},
		phases={[""]="Engaged"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 36627 or did == 36627 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("") TimerCreate("Unstable Ooze stacks","ucount",5) end,
		["COMBAT_LOG_EVENT_UNFILTERED"]=function(...) if (select(2,...))=="SPELL_CAST_START" and (select(10,...)) == (GetSpellInfo(69839)) then TimerSet("Unstable Ooze stacks", 0) end end,
		["UNIT_AURA"] = function(unit) if tonumber(UnitGUID(unit):sub(9,12),16) == 36899 then TimerSet("Unstable Ooze stacks",(select(4,UnitDebuff(unit,(GetSpellInfo(69558)))))) end end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Rotface"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- festergut
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("festergut",
	bosstable["Festergut"],
	{
		healthtrack={[36626]=true},
		manatrack={},
		phases={[""]="Engaged"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 36626 or did == 36626 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("") TimerCreate("Inhale Blight stacks","ucount",3) TimerCreate("Enrage", "dtime", 300) end,
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...)
			if (select(10,...)) == (GetSpellInfo(69165)) then
				if (select(2,...)) == "SPELL_AURA_APPLIED" then
					TimerSet("Inhale Blight stacks", 1)
				elseif (select(2,...)) == "SPELL_AURA_APPLIED_DOSE" then
					TimerSet("Inhale Blight stacks", (select(13,...)))
				elseif (select(2,...)) == "SPELL_AURA_REMOVED" then
					TimerSet("Inhale Blight stacks", 0)
				end
			end
		end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Festergut"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- putricide
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("putricide",
	bosstable["Professor Putricide"],
	{
		healthtrack={[36678]=true,[37562]=false,[37697]=false},
		manatrack={},
		phases={["1"]="Engaged", ["2"]="Goo & Gas", ["3"] = "Mutation"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 36678 or did == 33678 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 600) end,
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...) if (select(10,...)) == (GetSpellInfo(71621)) then EnterPhase("2") elseif (select(10,...)) == (GetSpellInfo(73122)) then EnterPhase("3") end end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Professor Putricide"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- valthiria dreamwalker
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("dreamwalker",
	bosstable["Valithria Dreamwalker"],
	{
		healthtrack={[36789]=true,[36791]=false,[37863]=false},
		manatrack={},
		phases={[""]="Engaged"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 37868 or did == 37868 then
				return true
			end
		end,
	},
	{
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("") end,
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Valithria Dreamwalker"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- sindragosa
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("sindragosa",
	bosstable["Sindragosa"],
	{
		healthtrack={[36853]=true,[36980]=false}, -- sindragosa + blocks
		manatrack={},
		phases={["1"]="Ground phase", ["2"]="Air phase",["3"]="Buffet phase"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 36853 or did == 36853 then
				return true
			end
		end,
	},
	{
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 600) end,
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...)
			if tonumber((select(3,...)):sub(9,12),16) == 36853 and not IsInPhase("3") then
				EnterPhase("1")
			elseif (select(9,...)) == 70126 and not IsInPhase("3") then
				EnterPhase("2")
			elseif (select(10,...)) == (GetSpellInfo(70128)) then
				EnterPhase("3")
			end
		end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Sindragosa"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- blood princes
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("bloodprinces",
	bosstable["Blood Prince Council"],
	{
		healthtrack={[37970]=true,[37972]=true,[37973]=true},
		manatrack={},
		phases={["V"]="Valanar empowered",["K"]="Keleseth empowered",["T"]="Taldaram empowered"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			local sip = (sid == 37970) or (sid == 37972) or (sid == 37973)
			local dip = (did == 37970) or (did == 37972) or (did == 37973)
			if (sip and not dip) or (dip and not sip) then
				return true
			end
		end,
	},
	{
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...)
			if (select(2,...)) == "SPELL_AURA_APPLIED" then
				local spellID = (select(9,...))
				if spellID == 70982 then
					EnterPhase("T")
				elseif spellID == 70981 then
					EnterPhase("K")
				elseif spellID == 70952 then
					EnterPhase("V")
				end
			end
		end,
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("V") TimerCreate("Enrage", "dtime", 600) end,
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
	}
)

if not loadSuccess then
	print("Load of "..bosstable["Blood Prince Council"].." failed: "..StatusSubscribe.locale[errorMsg])
end

-- bql
loadSuccess, errorMsg = StatusSubscribe:RegisterEncounter("lanathel",
	bosstable["Blood-Queen Lana'thel"],
	{
		healthtrack={[37955]=true},
		manatrack={},
		phases={["1"]="Ground phase",["2"]="Air phase"},
	},
	{
		events={"COMBAT_LOG_EVENT_UNFILTERED"},
		filter=function(event,...)
			local sid = tonumber((select(3,...)):sub(9,12),16)
			local did = tonumber((select(6,...)):sub(9,12),16)
			if sid == 37955 or did == 37955 then
				return true
			end
		end,
	},
	{
		["ENCOUNTER_ENGAGE"] = function() EnterPhase("1") TimerCreate("Enrage", "dtime", 330) TimerCreate("People bitten", "ucount", GetNumRaidMembers()) TimerCreate("People mind controlled", "ucount", GetNumRaidMembers())  end,
		["ALL_OUT_OF_COMBAT"] = function() DisableEncounter() end,
		["COMBAT_LOG_EVENT_UNFILTERED"] = function(...)
			if (select(10,...)) == (GetSpellInfo(70867)) then
				local pplbitten, pplmced = 0,0
				for n=1, GetNumRaidMembers() do
					if UnitAura("raid"..n, (GetSpellInfo(70867))) or UnitAura("raid"..n, (GetSpellInfo(70877))) then
						pplbitten = pplbitten+1
					elseif UnitAura("raid"..n, (GetSpellInfo(70923))) then
						pplmced = pplmced + 1
					end
				end
				if TimerValue("People bitten") ~= pplbitten then
					TimerSet("People bitten", pplbitten)
				end
				if TimerValue("People mind controlled") ~= pplmced then
					TimerSet("People mind controlled", pplmced)
				end
			end
			if (select(10,...)) == (GetSpellInfo(73070)) then
				EnterPhase("2")
			end
			if (select(2,...)) == "SWING_DAMAGE" then
				EnterPhase("1")
			end
		end,
	}
)
if not loadSuccess then
	print("Load of "..bosstable["Blood-Queen Lana'thel"].." failed: "..StatusSubscribe.locale[errorMsg])
end